==> ietf-netconf-notifications-1.4.3-sources.jar: org/opendaylight/yang/gen/v1/urn/ietf/params/xml/ns/netconf/notification/_1/_0/rev080714/StreamNameType.java <==
package org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.netconf.notification._1._0.rev080714;
import java.io.Serializable;
import java.beans.ConstructorProperties;
import java.util.Objects;

public class StreamNameType
 implements Serializable {
    private static final long serialVersionUID = 2107824323962254690L;
    private final java.lang.String _value;


    @ConstructorProperties("value")
    public StreamNameType(java.lang.String _value) {
    
    
        Objects.requireNonNull(_value, "Supplied value may not be null");
    
        this._value = _value;
    }
    
    /**
     * Creates a copy from Source Object.
     *
     * @param source Source object
     */
    public StreamNameType(StreamNameType source) {
        this._value = source._value;
    }

    public static StreamNameType getDefaultInstance(String defaultValue) {
        return new StreamNameType(defaultValue);
    }

    public java.lang.String getValue() {
        return _value;
    }


    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + Objects.hashCode(_value);
        return result;
    }

    @Override
    public boolean equals(java.lang.Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        StreamNameType other = (StreamNameType) obj;
        if (!Objects.equals(_value, other._value)) {
            return false;
        }
        return true;
    }

    @Override
    public java.lang.String toString() {
        java.lang.StringBuilder builder = new java.lang.StringBuilder(org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.netconf.notification._1._0.rev080714.StreamNameType.class.getSimpleName()).append(" [");
        boolean first = true;
    
        if (_value != null) {
            if (first) {
                first = false;
            } else {
                builder.append(", ");
            }
            builder.append("_value=");
            builder.append(_value);
        }
        return builder.append(']').toString();
    }
}

==> ietf-netconf-notifications-1.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/ietf/params/xml/ns/netconf/notification/_1/_0/rev080714/StreamNameType.java <==
package org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.netconf.notification._1._0.rev080714;
import com.google.common.base.MoreObjects;
import java.beans.ConstructorProperties;
import java.io.Serializable;
import java.lang.Override;
import java.lang.String;
import java.util.Objects;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.TypeObject;

public class StreamNameType
 implements TypeObject, Serializable {
    private static final long serialVersionUID = 2107824323962254690L;
    private final String _value;


    @ConstructorProperties("value")
    public StreamNameType(String _value) {
    
        Objects.requireNonNull(_value, "Supplied value may not be null");
    
        this._value = _value;
    }
    
    /**
     * Creates a copy from Source Object.
     *
     * @param source Source object
     */
    public StreamNameType(StreamNameType source) {
        this._value = source._value;
    }

    public static StreamNameType getDefaultInstance(String defaultValue) {
        return new StreamNameType(defaultValue);
    }

    public String getValue() {
        return _value;
    }


    @Override
    public int hashCode() {
        return CodeHelpers.wrapperHashCode(_value);
    }

    @Override
    public boolean equals(java.lang.Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        StreamNameType other = (StreamNameType) obj;
        if (!Objects.equals(_value, other._value)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper(StreamNameType.class);
        CodeHelpers.appendValue(helper, "_value", _value);
        return helper.toString();
    }
}
